@@ -4,7 +4,7 @@ use strict;
 use warnings FATAL => 'all';
 
 use version;
-our $VERSION = '1.04';
+our $VERSION = '1.05';
 
 # using Web::Simple in this context will implicitly make Prancer a subclass of
 # Web::Simple::Application. that will cause a number of things to be imported
@@ -218,6 +218,7 @@ sub import {
 
 sub to_psgi_app {
     my $self = shift;
+    croak "cannot call ->to_psgi_app before calling ->new" unless (ref($self) && $self->isa(__PACKAGE__));
 
     # get the PSGI app from Web::Simple and wrap middleware around it
     my $app = $self->SUPER::to_psgi_app();
@@ -238,7 +239,7 @@ sub dispatch_request {
     my ($self, $env) = @_;
 
     my $request = Prancer::Request->new($env);
-    my $response = Prancer::Response->new($env);
+    my $response = Prancer::Response->new();
     my $session = Prancer::Session->new($env);
 
     return $self->handler($env, $request, $response, $session);
@@ -508,8 +509,13 @@ the same terms as Perl itself.
 
 =over
 
-=item L<Plack>
-=item L<Web::Simple>
+=item
+
+L<Plack>
+
+=item
+
+L<Web::Simple>
 
 =back
 
