@@ -4,21 +4,21 @@ use strict;
 use warnings FATAL => 'all';
 
 use version;
-our $VERSION = '1.04';
+our $VERSION = '1.05';
 
 use Plack::Response;
 use Hash::MultiValue;
 use URI::Escape ();
-use HTTP::Headers;
+use HTTP::Headers::Fast;
 use Carp;
 
 # even though this *should* work automatically, it was not
 our @CARP_NOT = qw(Prancer Try::Tiny);
 
 sub new {
-    my ($class, $env) = @_;
+    my $class = shift;
     return bless({
-        '_response' => Plack::Response->new($env),
+        '_response' => Plack::Response->new(),
         '_cookies' => Hash::MultiValue->new(),
         '_headers' => Hash::MultiValue->new(),
     }, $class);
@@ -100,7 +100,7 @@ sub finalize {
     # response later. for whatever reason plack is being weird about this when
     # the same header name is being used more than once. though, i might be
     # doing it wrong.
-    my $headers = HTTP::Headers->new();
+    my $headers = HTTP::Headers::Fast->new();
 
     # add normal headers
     for my $key (keys %{$self->headers()}) {
